from setuptools import setup

setup(name='crazy-distributions',
      version='0.1',
      description='Gaussian and Binomial distributions',
      author='Harshit Rai',
      author_email='harshitrai68@gmail.com',
      packages=['crazy-distributions'],
      zip_safe=False)
